@@ -1,8 +1,7 @@
 import abc
 import copy
 import json
-from types import NoneType
-from typing import Any
+from typing import Any, Optional
 
 from PyQt6.QtWidgets import (
     QVBoxLayout,
@@ -22,7 +21,9 @@ from function2widgets.widget import InvalidValueError
 from function2widgets.widgets._sourcecodeedit import _SourceCodeEdit, DEFAULT_CONFIGS
 from function2widgets.widgets.base import CommonParameterWidget
 
-JsonTopLevelTypes = (dict, list, tuple, int, str, float, bool, NoneType)
+_NoneType = type(None)
+
+JsonTopLevelTypes = (dict, list, tuple, int, str, float, bool, _NoneType)
 
 
 class BaseSourceCodeEditDialog(QDialog):
@@ -94,23 +95,22 @@ class UniversalSourceCodeEditDialog(BaseSourceCodeEditDialog):
     def __init__(self, configs: dict = None, window_title: str = "", parent=None):
         super().__init__(configs=configs, window_title=window_title, parent=parent)
 
-    def set_value(self, obj: str | None, none_as_empty: bool = False, *args, **kwargs):
+    def set_value(self, obj: Optional[str], *args, **kwargs):
         if obj is None:
-            if none_as_empty:
-                obj = ""
-            else:
-                return
+            obj = ""
         self._code_edit.setText(obj)
 
-    def get_value(self, empty_as_none: bool = False, *args, **kwargs) -> str | None:
+    def get_value(self, empty_as_none: bool = False, *args, **kwargs) -> Optional[str]:
         text = self._code_edit.text()
-        if not text and empty_as_none:
+        if not text:
             return None
         else:
             return text
 
 
 class BaseSourceCodeEditor(CommonParameterWidget):
+    SET_DEFAULT_ON_INIT = True
+
     def __init__(
         self,
         configs: dict = None,
@@ -118,15 +118,15 @@ class BaseSourceCodeEditor(CommonParameterWidget):
         window_title: str = None,
         display_current_value: bool = True,
         default: Any = None,
-        stylesheet: str | None = None,
-        parent: QWidget | None = None,
+        stylesheet: Optional[str] = None,
+        parent: Optional[QWidget] = None,
     ):
 
         if configs is None:
             configs = DEFAULT_CONFIGS.copy()
 
-        self._value_widget: QPushButton | None = None
-        self._display_widget: QPlainTextEdit | None = None
+        self._value_widget: Optional[QPushButton] = None
+        self._display_widget: Optional[QPlainTextEdit] = None
         self._display_current_value = display_current_value
 
         self._current_value = default
@@ -137,7 +137,8 @@ class BaseSourceCodeEditor(CommonParameterWidget):
 
         super().__init__(default=default, stylesheet=stylesheet, parent=parent)
 
-        self.set_value(self.default)
+        if self.SET_DEFAULT_ON_INIT:
+            self.set_value(self.default)
 
     # noinspection PyUnresolvedReferences
     def setup_center_widget(self, center_widget: QWidget):
@@ -147,6 +148,7 @@ class BaseSourceCodeEditor(CommonParameterWidget):
         self._display_widget = QPlainTextEdit(parent=center_widget)
         self._display_widget.setReadOnly(True)
         if self._display_current_value:
+            self._update_current_value_display(self._current_value)
             self._display_widget.show()
         else:
             self._display_widget.hide()
@@ -195,16 +197,22 @@ class BaseSourceCodeEditor(CommonParameterWidget):
 
 
 class UniversalSourceCodeEditor(BaseSourceCodeEditor):
+    SET_DEFAULT_ON_INIT = False
+
     def __init__(
         self,
         configs: dict = None,
         edit_button_text: str = None,
         window_title: str = None,
         display_current_value: bool = True,
-        default: str | None = None,
-        stylesheet: str | None = None,
-        parent: QWidget | None = None,
+        default: Optional[str] = None,
+        stylesheet: Optional[str] = None,
+        parent: Optional[QWidget] = None,
     ):
+        if default is not None and not isinstance(default, str):
+            raise InvalidValueError(
+                QApplication.tr(f"default must be str, got {type(default)}")
+            )
         super().__init__(
             configs=configs,
             edit_button_text=edit_button_text,
@@ -215,12 +223,12 @@ class UniversalSourceCodeEditor(BaseSourceCodeEditor):
             parent=parent,
         )
 
-    def get_value(self, *args, **kwargs) -> str | None:
+    def get_value(self, *args, **kwargs) -> Optional[str]:
         return super().get_value(*args, **kwargs)
 
-    def set_value(self, value: str | None, *args, **kwargs):
+    def set_value(self, value: Optional[str], *args, **kwargs):
         if value is not None and not isinstance(value, str):
-            raise TypeError(self.tr("value must be None or str"))
+            raise TypeError(self.tr(f"value must be None or str, got {type(value)}"))
         super().set_value(value, *args, **kwargs)
 
     def source_code_dialog(self) -> UniversalSourceCodeEditDialog:
@@ -291,16 +299,18 @@ class JsonEditDialog(BaseSourceCodeEditDialog):
 
 
 class JsonEditor(BaseSourceCodeEditor):
+    SET_DEFAULT_ON_INIT = False
+
     def __init__(
         self,
         top_level_types: tuple = JsonTopLevelTypes,
+        default: Any = None,
         configs: dict = None,
         edit_button_text: str = None,
         window_title: str = None,
         display_current_value: bool = True,
-        default: Any = None,
-        stylesheet: str | None = None,
-        parent: QWidget | None = None,
+        stylesheet: Optional[str] = None,
+        parent: Optional[QWidget] = None,
     ):
 
         if configs is None:
@@ -308,7 +318,7 @@ class JsonEditor(BaseSourceCodeEditor):
         configs["Lexer"] = "JSON"
 
         if default is not None:
-            self._top_level_types = remove_tuple_element(top_level_types, NoneType)
+            self._top_level_types = remove_tuple_element(top_level_types, _NoneType)
         else:
             self._top_level_types = top_level_types
 
@@ -342,75 +352,79 @@ class JsonEditor(BaseSourceCodeEditor):
     def fetch_result_from_dialog(self, dialog: JsonEditDialog):
         return dialog.current_value
 
-    def get_value(self, *args, **kwargs) -> Any | None:
+    def get_value(self, *args, **kwargs) -> Any:
         return super().get_value(*args, **kwargs)
 
-    def set_value(self, value: Any | None, *args, **kwargs):
+    def set_value(self, value: Any, *args, **kwargs):
         super().set_value(value, *args, **kwargs)
 
 
 class ListEditor(JsonEditor):
-    TYPE_RESTRICTIONS = (list, NoneType)
+    SET_DEFAULT_ON_INIT = False
+
+    TYPE_RESTRICTIONS = (list, _NoneType)
 
     def __init__(
         self,
+        default: list = None,
         configs: dict = None,
         edit_button_text: str = None,
         window_title: str = None,
         display_current_value: bool = True,
-        default: list = None,
-        stylesheet: str | None = None,
-        parent: QWidget | None = None,
+        stylesheet: Optional[str] = None,
+        parent: Optional[QWidget] = None,
     ):
         super().__init__(
             top_level_types=self.TYPE_RESTRICTIONS,
+            default=default,
             configs=configs,
             edit_button_text=edit_button_text,
             window_title=window_title,
             display_current_value=display_current_value,
-            default=default,
             stylesheet=stylesheet,
             parent=parent,
         )
 
-    def get_value(self, *args, **kwargs) -> list | None:
+    def get_value(self, *args, **kwargs) -> Optional[list]:
         return super().get_value(*args, **kwargs)
 
-    def set_value(self, value: list | None, *args, **kwargs):
+    def set_value(self, value: Optional[list], *args, **kwargs):
         if isinstance(value, (tuple, set)):
             value = list(value)
         super().set_value(value, *args, **kwargs)
 
 
 class TupleEditor(JsonEditor):
-    TYPE_RESTRICTIONS = (list, tuple, NoneType)
+    SET_DEFAULT_ON_INIT = False
+    TYPE_RESTRICTIONS = (list, tuple, _NoneType)
 
     def __init__(
         self,
+        default: tuple = None,
         configs: dict = None,
         edit_button_text: str = None,
         window_title: str = None,
         display_current_value: bool = True,
-        default: tuple = None,
-        stylesheet: str | None = None,
-        parent: QWidget | None = None,
+        stylesheet: Optional[str] = None,
+        parent: Optional[QWidget] = None,
     ):
         super().__init__(
+            top_level_types=self.TYPE_RESTRICTIONS,
             configs=configs,
+            default=default,
             edit_button_text=edit_button_text,
             window_title=window_title,
             display_current_value=display_current_value,
-            default=default,
             stylesheet=stylesheet,
             parent=parent,
         )
 
-    def set_value(self, value: tuple | None, *args, **kwargs):
+    def set_value(self, value: Optional[tuple], *args, **kwargs):
         if isinstance(value, list):
             value = tuple(value)
         super().set_value(value, *args, **kwargs)
 
-    def get_value(self, *args, **kwargs) -> tuple | None:
+    def get_value(self, *args, **kwargs) -> Optional[tuple]:
         value = super().get_value(*args, **kwargs)
         if value is None:
             return None
@@ -427,33 +441,34 @@ class TupleEditor(JsonEditor):
 
 
 class DictEditor(JsonEditor):
-    TYPE_RESTRICTIONS = (dict, NoneType)
+    SET_DEFAULT_ON_INIT = False
+    TYPE_RESTRICTIONS = (dict, _NoneType)
 
     def __init__(
         self,
+        default: dict = None,
         configs: dict = None,
         edit_button_text: str = None,
         window_title: str = None,
         display_current_value: bool = True,
-        default: dict = None,
-        stylesheet: str | None = None,
-        parent: QWidget | None = None,
+        stylesheet: Optional[str] = None,
+        parent: Optional[QWidget] = None,
     ):
         super().__init__(
             top_level_types=self.TYPE_RESTRICTIONS,
+            default=default,
             configs=configs,
             edit_button_text=edit_button_text,
             window_title=window_title,
             display_current_value=display_current_value,
-            default=default,
             stylesheet=stylesheet,
             parent=parent,
         )
 
-    def get_value(self, *args, **kwargs) -> dict | None:
+    def get_value(self, *args, **kwargs) -> Optional[dict]:
         return super().get_value(*args, **kwargs)
 
-    def set_value(self, value: dict | None, *args, **kwargs):
+    def set_value(self, value: Optional[dict], *args, **kwargs):
         super().set_value(value, *args, **kwargs)
 
 
@@ -470,16 +485,18 @@ def __test_main():
     )
     source_code_editor.set_label("UniversalSourceCodeEditor")
 
-    json_editor = JsonEditor(display_current_value=False, default=None, parent=wind)
+    json_editor = JsonEditor(default=123, display_current_value=True, parent=wind)
     json_editor.set_label("JsonEditor")
 
-    json_editor2 = ListEditor(display_current_value=False, default=[], parent=wind)
+    json_editor2 = ListEditor(
+        default=[1, 2, 3], display_current_value=True, parent=wind
+    )
     json_editor2.set_label("ListEditor")
-    a = [1, 2, 3]
-    print(id(a))
-    json_editor2.set_value(a)
-    b = json_editor2.get_value()
-    print(id(b))
+    # a = [1, 2, 3]
+    # print(id(a))
+    # json_editor2.set_value(a)
+    # b = json_editor2.get_value()
+    # print(id(b))
 
     json_editor3 = DictEditor(default=None, parent=wind)
     json_editor3.set_label("DictEditor")
